==> aliyun-python-sdk-arms-2.7.24.tar.gz: aliyun-python-sdk-arms-2.7.24/aliyunsdkarms/request/v20190808/DescribeContactGroupsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkarms.endpoint import endpoint_data

class DescribeContactGroupsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DescribeContactGroups','arms')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Size(self): # Long
		return self.get_query_params().get('Size')

	def set_Size(self, Size):  # Long
		self.add_query_param('Size', Size)
	def get_IsDetail(self): # Boolean
		return self.get_query_params().get('IsDetail')

	def set_IsDetail(self, IsDetail):  # Boolean
		self.add_query_param('IsDetail', IsDetail)
	def get_Page(self): # Long
		return self.get_query_params().get('Page')

	def set_Page(self, Page):  # Long
		self.add_query_param('Page', Page)
	def get_ContactGroupName(self): # String
		return self.get_query_params().get('ContactGroupName')

	def set_ContactGroupName(self, ContactGroupName):  # String
		self.add_query_param('ContactGroupName', ContactGroupName)

==> aliyun-python-sdk-arms-2.7.27.tar.gz: aliyun-python-sdk-arms-2.7.27/aliyunsdkarms/request/v20190808/DescribeContactGroupsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkarms.endpoint import endpoint_data

class DescribeContactGroupsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DescribeContactGroups','arms')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Size(self): # Long
		return self.get_query_params().get('Size')

	def set_Size(self, Size):  # Long
		self.add_query_param('Size', Size)
	def get_GroupIds(self): # String
		return self.get_query_params().get('GroupIds')

	def set_GroupIds(self, GroupIds):  # String
		self.add_query_param('GroupIds', GroupIds)
	def get_IsDetail(self): # Boolean
		return self.get_query_params().get('IsDetail')

	def set_IsDetail(self, IsDetail):  # Boolean
		self.add_query_param('IsDetail', IsDetail)
	def get_Page(self): # Long
		return self.get_query_params().get('Page')

	def set_Page(self, Page):  # Long
		self.add_query_param('Page', Page)
	def get_ContactGroupName(self): # String
		return self.get_query_params().get('ContactGroupName')

	def set_ContactGroupName(self, ContactGroupName):  # String
		self.add_query_param('ContactGroupName', ContactGroupName)
